@@ -5,12 +5,12 @@ import os.path
 
 import akshare as ak
 import mootdx.utils.holiday as mooUtils
-import numpy as np
 import pandas as pd
 import requests
 from mootdx.quotes import Quotes
 from tqdm import tqdm
 
+from quant1x.formula.formula import *
 from quant1x.data import *
 
 # 中国内地证券市场
@@ -52,15 +52,8 @@ class DataHandler:
 
         self.__stock_list = {}
         # 自选股csv文件路径
-        # 从自选股中获取证券代码列表
-        # stock_list.columns = [
-        #     "market",
-        #     "code",
-        #     "name",
-        # ]
         zxg_csv = self.__path + '/zxg.csv'
         self.__stock_list = pd.read_csv(zxg_csv)
-        # print(self.__stock_list)
 
         # 标准市场
         self.__client = Quotes.factory(market='std', multithread=True, heartbeat=True)
@@ -569,6 +562,12 @@ class DataHandler:
         df['委比(BidAskPct)'] = np.repeat(0.00, dLen)
         # 量比(VolumePct)
         df['量比(VolumePct)'] = np.repeat(0.00, dLen)
+        vol = temp_df["成交量"].copy()
+        bl = vol.rolling(5).sum() / (240 * 5)
+        ms = self.__client.minute(symbol=code)
+        minutes = len(ms) if len(ms) else 240
+        df['量比(VolumePct)'] = (vol / minutes) / REF(bl, 1)
+
         # 净流入量(NetInflowVolume)
         df['净流入量(NetInflowVolume)'] = np.repeat(0.00, dLen)
         # 净流入额(NetInflowAmount)
@@ -611,9 +610,11 @@ class DataHandler:
                 # df.iloc[idx] = row
                 try:
                     info = xdxr.loc[dt]
-                    if info['category'] != 5:
+                    if info is None:
                         continue
-                    if info is None or info['panhouliutong'] < 1:
+                    if isinstance(info, np.int64) and info['category'] != 5:
+                        continue
+                    if isinstance(info['panhouliutong'], np.float64) and info['panhouliutong'] < 1:
                         continue
                     if not dr is None:
                         dr = info
@@ -621,7 +622,7 @@ class DataHandler:
                     dr = info
                 except KeyError:
                     pass
-                if not dr is None:
+                if not dr is None and isinstance(dr['panhouliutong'], np.float64):
                     df.loc[idx, '流通股(ShsFloat)'] = dr['panhouliutong'] * 10000
                     df.loc[idx, '流通值(FloatCAP)'] = row['当日收盘价(Close)'] * dr['panhouliutong'] * 10000
                     df.loc[idx, '总股本(SharedOutstanding)'] = dr['houzongguben'] * 10000
